@@ -53,7 +53,7 @@
 #include <mecab.h>
 #endif
 
-#ifdef DEBUG_CONF_LOCK
+#ifdef HAVE_DEBUG
 #include <assert.h>
 #endif
 
@@ -644,6 +644,9 @@ typedef struct {
         int     	origin;
         int             weight; /* origin-dependent weight */
         int		match;
+        size_t		secno;  /* Which section to search in */
+        size_t		phrpos; /* 0 means "not in phrase"    */
+        size_t		phrlen; /* phase length               */
 } UDM_WIDEWORD;
 
 typedef struct {
@@ -836,8 +839,6 @@ typedef struct udm_indexer_struct{
         urlid_t ServerIdCacheId[UDM_SERVERID_CACHE_SIZE];
         size_t  pServerIdCache;
 
-        int     Locked[UDM_LOCK_MAX];  /**< is locked, how many times */
-
 #ifdef USE_TRACE
   FILE *TR;
 #endif
