@@ -25,7 +25,7 @@
 #endif
 
 /* Backend */
-#if (HAVE_ODBC||HAVE_MYSQL||HAVE_PGSQL||HAVE_IBASE||HAVE_ORACLE8||HAVE_CTLIB||HAVE_SQLITE)
+#if (HAVE_ODBC||HAVE_MYSQL||HAVE_PGSQL||HAVE_IBASE||HAVE_ORACLE8||HAVE_CTLIB||HAVE_SQLITE||HAVE_SQLITE3)
 #define HAVE_SQL 1
 #endif
 
@@ -166,4 +166,17 @@ extern void UdmViolationExit(void *);
 #define UdmViolationExit(x)
 #endif
 
+#ifdef HAVE_DEBUG
+  #define UDM_ASSERT(x)  assert(x)
+  #ifdef HAVE_PTHREAD
+    #define UDM_ASSERT_MUTEX_OWNER(x) UDM_ASSERT((x)->count > 0 && pthread_equal(pthread_self(),(x)->thread))
+  #else
+    #define UDM_ASSERT_MUTEX_OWNER(x)
+  #endif
+#else
+  #define UDM_ASSERT(x)
+  #define UDM_ASSERT_MUTEX_OWNER(x) 
+#endif
+
+
 #endif /* _UDM_CONFIG_H */
