@@ -178,6 +178,10 @@ extern size_t UdmBlobCacheAdd (UDM_BLOB_CACHE *cache, urlid_t url_id,
                                unsigned char secno, const char *word,
                                size_t nintags, const char *intag,
                                size_t intag_length);
+extern size_t UdmBlobCacheAdd2(UDM_BLOB_CACHE *cache, urlid_t url_id,
+                               unsigned char secno, char *word,
+                               size_t nintags, char *intag,
+                               size_t intag_length);
 extern void UdmBlobCacheSort (UDM_BLOB_CACHE *cache);
 
 extern UDM_WORD_CACHE *UdmWordCacheInit (UDM_WORD_CACHE *cache);
