@@ -105,16 +105,18 @@ typedef struct {
 } UDM_MULTI_CACHE;
 
 typedef struct {
-	unsigned char secno;
 	char *word;
 	urlid_t url_id;
 	size_t nintags;    /* Length in coords */
 	size_t ntaglen;    /* Length in bytes  */
 	char *intags;
+	unsigned char secno;
+	unsigned char freeme; /* Whether word was alloced */
 } UDM_BLOB_CACHE_WORD;
 
 typedef struct {
 	unsigned char free;
+	size_t errors;
 	size_t nwords;
 	size_t awords;
 	UDM_BLOB_CACHE_WORD *words;
