@@ -24,6 +24,10 @@ int  UdmSpellListListAdd(UDM_SPELLLISTLIST *L,
                          const char *lang, const char *cset, const char *name);
 int  UdmSpellListListLoad(UDM_SPELLLISTLIST *L,
                          char *err, size_t errlen);
+int  UdmSpellListListWriteHash(UDM_SPELLLISTLIST *L,
+                               char *err, size_t errlen);
+int  UdmSpellDump(UDM_SPELLLISTLIST *L, UDM_AFFIXLISTLIST *A,
+                  char *err, size_t errlen);
 
 void UdmAffixListListInit(UDM_AFFIXLISTLIST *L);
 void UdmAffixListListFree(UDM_AFFIXLISTLIST *L);
