@@ -22,7 +22,10 @@
 #define UDM_SQL_HAVE_TRUNCATE    2
 #define UDM_SQL_HAVE_SUBSELECT   4
 #define UDM_SQL_HAVE_LIMIT       8
-
+#define UDM_SQL_HAVE_TOP	16  /* SELECT TOP 10 FROM t1              */
+#define UDM_SQL_HAVE_BIND       32  /* whether to use prepared statements */
+#define UDM_SQL_HAVE_0xHEX	64  /* INSERT INTO t1 VALUES (0xAABBCC)   */
+#define UDM_SQL_HAVE_STDHEX    128  /* INSERT INTO t1 VALUES (X'AABBCC')  */
 
 extern void DecodeHexStr (char *src, UDM_PSTR *dst, size_t size);
 char           *UdmDBEscStr(int DBType,char *to,const char *from,size_t len);
