@@ -23,6 +23,9 @@ extern int UdmWordListFree(UDM_WORDLIST * List);
 extern UDM_WORDLIST * UdmWordListInit(UDM_WORDLIST * List);
 
 
+extern void UdmWideWordInit(UDM_WIDEWORD *W);
+extern void UdmWideWordFree(UDM_WIDEWORD *W);
+
 extern UDM_WIDEWORDLIST * UdmWideWordListInit(UDM_WIDEWORDLIST * List);
 extern size_t UdmWideWordListAdd(UDM_WIDEWORDLIST * List,UDM_WIDEWORD * Word);
 extern void UdmWideWordListFree(UDM_WIDEWORDLIST * List);
