@@ -881,6 +881,15 @@ static int add_srv_table(void *Cfg, size_t ac,char **av)
   UDM_DBLIST      dbl;
   UDM_DB    *db;
   
+  /*
+    Skip ServerTable when loading for search, not for indexing.
+    Useful when the ServerTable options are written in a shared
+    include.conf file together with DBAddr options, and this file
+    is included from both indexer.conf and search.htm
+  */
+  if(!(C->flags & UDM_FLAG_ADD_SERV))
+    return UDM_OK;
+
   UdmDBListInit(&dbl);
   UdmDBListAdd(&dbl, av[1], UDM_OPEN_MODE_READ);
   db = &dbl.db[0];
@@ -923,6 +932,17 @@ static int add_limit(void *Cfg, size_t ac,char **av)
   return UDM_OK;
 }
 
+
+static int add_user_score(void *Cfg, size_t ac,char **av)
+{
+  UDM_CFG  *C=(UDM_CFG*)Cfg;
+  UDM_ENV  *Conf=C->Indexer->Conf;
+  char name[128];
+  udm_snprintf(name, sizeof(name), "Score.%s", av[1]);
+  UdmVarListReplaceStr(&Conf->Vars, name, av[2]);
+  return UDM_OK;
+}
+
 static int flush_srv_table(void *Cfg, size_t ac,char **av)
 {
   UDM_CFG  *C=(UDM_CFG*)Cfg;
@@ -1296,6 +1316,7 @@ static UDM_CONFCMD commands[] =
   {"MinCoordFactor",       1,1,   env_rpl_num_var},
   {"NumWordFactor",        1,1,   env_rpl_var},
   {"NumDistinctWordFactor",1,1,   env_rpl_num_var},
+  {"UserScoreFactor",      1,1,   env_rpl_num_var},
   {"URLDataThreshold",     1,1,   env_rpl_num_var},
   {"DocSizeWeight",        1,1,   env_rpl_num_var},
   {"RelevancyFactor",      1,1,   env_rpl_num_var},
@@ -1401,6 +1422,7 @@ static UDM_CONFCMD commands[] =
   {"LoadChineseList",      0,2,   add_chinese},
   {"LoadThaiList",         0,2,   add_thai},
   {"Limit",                1,2,   add_limit},
+  {"UserScore",            1,2,   add_user_score},
   {"ServerTable",          1,1,   add_srv_table},
   {"FlushServerTable",     0,0,   flush_srv_table},
   {"DBListFree",           0,0,   dblist_free},
@@ -1503,7 +1525,7 @@ static int EnvLoad(UDM_CFG *Cfg,const char *cname)
     
     if(str1[0]=='#')continue;
     for (end = str1 + (str1len = strlen(str1)) - 1 ;
-         (end>=str1) && (*end=='\r'||*end=='\n'||*end==' ') ;
+         (end>=str1) && (*end=='\r'||*end=='\n'||*end==' '||*end=='\t') ;
          *end--='\0');
     if(!str1[0])continue;
     
