@@ -36,12 +36,12 @@ static int AddOneCrossWord(UDM_DOCUMENT * Doc,UDM_CROSSWORD * CrossWord){
 	/* Realloc memory when required  */
 	if(Doc->CrossWords.ncrosswords>=Doc->CrossWords.mcrosswords){
 		Doc->CrossWords.mcrosswords+=WSIZE;
-		Doc->CrossWords.CrossWord=(UDM_CROSSWORD *)realloc(Doc->CrossWords.CrossWord,Doc->CrossWords.mcrosswords*sizeof(UDM_CROSSWORD));
+		Doc->CrossWords.CrossWord=(UDM_CROSSWORD *)UdmRealloc(Doc->CrossWords.CrossWord,Doc->CrossWords.mcrosswords*sizeof(UDM_CROSSWORD));
 	}
 
 	/* Add new word */
-	Doc->CrossWords.CrossWord[Doc->CrossWords.ncrosswords].word = (char*)strdup(CrossWord->word);
-	Doc->CrossWords.CrossWord[Doc->CrossWords.ncrosswords].url = (char*)strdup(CrossWord->url);
+	Doc->CrossWords.CrossWord[Doc->CrossWords.ncrosswords].word = (char*)UdmStrdup(CrossWord->word);
+	Doc->CrossWords.CrossWord[Doc->CrossWords.ncrosswords].url = (char*)UdmStrdup(CrossWord->url);
 	Doc->CrossWords.CrossWord[Doc->CrossWords.ncrosswords].weight=CrossWord->weight;
 	Doc->CrossWords.CrossWord[Doc->CrossWords.ncrosswords].pos=CrossWord->pos;
 	Doc->CrossWords.ncrosswords++;
