@@ -1149,7 +1149,7 @@ static UDM_SQLDB_DRIVER SQLDriver[]=
     are more then 1500. We'd better have to fix code to avoid 
     big INs instead of hidding DBSQL_IN.
     */
-    UDM_SQL_HAVE_GROUPBY,
+    UDM_SQL_HAVE_GROUPBY | UDM_SQL_HAVE_BIND,
     &udm_sqldb_ibase_handler,
   },
 #endif
@@ -1236,9 +1236,10 @@ static UDM_SQLDB_DRIVER SQLDriver[]=
     &udm_sqldb_odbc_handler,
   },
   {
+    /* Bind does not seem to work with BYTEA in Windows */
     "odbc-pgsql", UDM_DB_PGSQL, UDM_DB_ODBC, 1,
     UDM_SQL_HAVE_LIMIT      | UDM_SQL_HAVE_GROUPBY |
-    UDM_SQL_HAVE_SUBSELECT  | UDM_SQL_HAVE_BIND,
+    UDM_SQL_HAVE_SUBSELECT  /*| UDM_SQL_HAVE_BIND*/,
     &udm_sqldb_odbc_handler,
   },
   {
@@ -1388,7 +1389,8 @@ int UdmDBSetAddr(UDM_DB *db, const char *dbaddr, int mode)
         db->DBType != UDM_DB_MIMER &&
         db->DBType != UDM_DB_ORACLE8 &&
         db->DBType != UDM_DB_DB2 &&
-        db->DBType != UDM_DB_PGSQL)
+        db->DBType != UDM_DB_PGSQL &&
+        db->DBType != UDM_DB_IBASE)
       return UDM_ERROR;
   }
 
@@ -1933,15 +1935,16 @@ UDM_BLOB_CACHE *UdmBlobCacheInit (UDM_BLOB_CACHE *cache)
   {
     cache = UdmMalloc(sizeof(UDM_BLOB_CACHE));
     if (! cache) return(NULL);
-    cache->free = 1;
+    cache->free= 1;
   }
   else
   {
-    cache->free = 0;
+    cache->free= 0;
   }
-  cache->nwords = 0;
-  cache->awords = 0;
-  cache->words = NULL;
+  cache->errors= 0;
+  cache->nwords= 0;
+  cache->awords= 0;
+  cache->words= NULL;
 
   return(cache);
 }
@@ -1949,76 +1952,127 @@ UDM_BLOB_CACHE *UdmBlobCacheInit (UDM_BLOB_CACHE *cache)
 void UdmBlobCacheFree (UDM_BLOB_CACHE *cache)
 {
   size_t i;
-  if (! cache) return;
   for (i= 0; i < cache->nwords; i++)
   {
-    UDM_FREE(cache->words[i].word);
-    UDM_FREE(cache->words[i].intags);
+    if (cache->words[i].freeme)
+      UDM_FREE(cache->words[i].word);
   }
 
   UdmFree(cache->words);
-  cache->nwords = 0;
-  cache->awords = 0;
-  cache->words = NULL;
+  cache->errors= 0;
+  cache->nwords= 0;
+  cache->awords= 0;
+  cache->words= NULL;
 
   if (cache->free) UdmFree(cache);
 }
 
+
+static inline int
+UdmBlobCacheCheckValue(urlid_t url_id, unsigned char secno,
+                       const char *word, size_t nintags,
+                       const char *intag, size_t intaglen)
+{
+  if (! url_id)
+  {
+    fprintf(stderr, "url_id variable empty\n");
+    return 1;
+  }
+  if (! secno)
+  {
+    fprintf(stderr, "secno variable empty\n");
+    return 1;
+  }
+  if (! word)
+  {
+    fprintf(stderr, "word variable empty\n");
+    return 1;
+  }
+  if (! nintags)
+  {
+    fprintf(stderr, "nintags variable empty\n");
+    return 1;
+  }
+  if (! intag)
+  {
+    fprintf(stderr, "intag variable empty\n");
+    return 1;
+  }
+  return 0;
+}
+
+
+static inline int
+UdmBlobCacheRealloc(UDM_BLOB_CACHE *cache)
+{
+  if (cache->nwords == cache->awords)
+  {
+    UDM_BLOB_CACHE_WORD *tmp;
+    size_t nbytes= (cache->awords + 256) * sizeof(UDM_BLOB_CACHE_WORD);
+    tmp= UdmRealloc(cache->words, nbytes);
+    if (!tmp)
+    {
+      cache->errors++;
+      if (cache->errors < 10 || (cache->errors % 2048) == 0)
+      fprintf(stderr, "BlobCacheRealloc: failed %d times: %d bytes, %d records\n",
+              cache->errors, nbytes, (cache->awords + 256));
+      return 1;
+    }
+    cache->words = tmp;
+    cache->awords += 256;
+  }
+  return 0;
+}
+
+
 size_t UdmBlobCacheAdd (UDM_BLOB_CACHE *cache, urlid_t url_id,
                         unsigned char secno, const char *word,
                         size_t nintags, const char *intag, size_t intaglen)
 {
-  if (! cache)
-  {
-    fprintf(stderr, "Cache variable empty\n");
-    return(0);
-  }
-  if (! url_id)
-  {
-    fprintf(stderr, "url_id variable empty\n");
-    return(0);
-  }
-  if (! secno)
-  {
-    fprintf(stderr, "secno variable empty\n");
-    return(0);
-  }
-  if (! word)
-  {
-    fprintf(stderr, "word variable empty\n");
-    return(0);
-  }
-  if (! nintags)
-  {
-    fprintf(stderr, "nintags variable empty\n");
-    return(0);
-  }
-  if (! intag)
-  {
-    fprintf(stderr, "intag variable empty\n");
-    return(0);
-  }
+  size_t word_len;
+  UDM_BLOB_CACHE_WORD *W;
+  
+  if (UdmBlobCacheCheckValue(url_id, secno, word, nintags, intag, intaglen) ||
+      UdmBlobCacheRealloc(cache))
+    return 0;
+  
+  word_len= strlen(word);
+  W= &cache->words[cache->nwords];
+  W->secno= secno;
+  W->url_id= url_id;
+  W->nintags= nintags;
+  W->ntaglen= intaglen;
+  W->word= UdmMalloc(word_len + intaglen + 2);
+  W->intags= W->word + word_len + 1;
+  memcpy(W->word, word, word_len + 1);
+  memcpy(W->intags, intag, intaglen);
+  W->intags[intaglen]= '\0';
+  W->freeme= 1;
 
-  if (cache->nwords == cache->awords)
-  {
-    UDM_BLOB_CACHE_WORD *tmp;
-    tmp = UdmRealloc(cache->words, (cache->awords + 256) * sizeof(UDM_BLOB_CACHE_WORD));
-    if (! tmp)
-    {
-      fprintf(stderr, "Realloc failed while adding word\n");
-      return(0);
-    }
-    cache->words = tmp;
-    cache->awords += 256;
-  }
-  cache->words[cache->nwords].secno = secno;
-  cache->words[cache->nwords].word = UdmStrdup(word);
-  cache->words[cache->nwords].url_id = url_id;
-  cache->words[cache->nwords].nintags = nintags;
-  cache->words[cache->nwords].intags = UdmMalloc(intaglen+1);
-  memcpy(cache->words[cache->nwords].intags,intag,intaglen);
-  cache->words[cache->nwords].intags[intaglen]= '\0';
-  cache->words[cache->nwords].ntaglen = intaglen;
+  cache->nwords++;
+
+  return(1);
+}
+
+
+size_t UdmBlobCacheAdd2(UDM_BLOB_CACHE *cache, urlid_t url_id,
+                        unsigned char secno, char *word,
+                        size_t nintags, char *intag, size_t intaglen)
+{
+  UDM_BLOB_CACHE_WORD *W;
+  
+  if (UdmBlobCacheCheckValue(url_id, secno, word, nintags, intag, intaglen) ||
+      UdmBlobCacheRealloc(cache))
+    return 0;
+  
+  W= &cache->words[cache->nwords];
+  W->secno= secno;
+  W->url_id= url_id;
+  W->nintags= nintags;
+  W->ntaglen= intaglen;
+  W->word= word;
+  W->intags= intag;
+  W->freeme= 0;
 
   cache->nwords++;
 
