@@ -28,6 +28,7 @@
 #include "udm_xmalloc.h"
 #include "udm_sgml.h"
 #include "udm_url.h"
+#include "udm_vars.h"
 
 /* Max URLs in cache: 4K URLs will use about 200K of RAM         */
 /* This should be a configurable parameter but we'll use 4K now  */
@@ -42,6 +43,14 @@ UDM_HREF *UdmHrefInit(UDM_HREF * H)
 }
 
 
+void UdmHrefFree(UDM_HREF * H)
+{
+  if (H->url)
+    UdmFree(H->url);
+  UdmVarListFree(&H->Vars);
+}
+
+
 /* Function to sort URLs in alphabetic order */
 static int cmphrefs(const void * v1, const void * v2)
 {
@@ -52,7 +61,7 @@ static int cmphrefs(const void * v1, const void * v2)
 __C_LINK int __UDMCALL UdmHrefListAdd(UDM_HREFLIST * HrefList,UDM_HREF * Href)
 {
   int l,r,c,res;
-  size_t i,len;
+  size_t len;
   char *ehref;
   
   /* Don't add an empty link */
@@ -79,6 +88,9 @@ __C_LINK int __UDMCALL UdmHrefListAdd(UDM_HREFLIST * HrefList,UDM_HREF * Href)
       HrefList->Href[c].server_id = Href->server_id;
       HrefList->Href[c].rec_id = Href->rec_id;
       HrefList->Href[c].max_doc_per_site = Href->max_doc_per_site;
+      UdmVarListFree(&HrefList->Href[c].Vars);
+      UdmVarListInit(&HrefList->Href[c].Vars);
+      UdmVarListReplaceLst(&HrefList->Href[c].Vars, &Href->Vars, NULL, "*");
       UDM_FREE(ehref);
       return(0);
     }
@@ -89,19 +101,22 @@ __C_LINK int __UDMCALL UdmHrefListAdd(UDM_HREFLIST * HrefList,UDM_HREF * Href)
   }
   
   /* Find in unsorted part */
-  for(i=HrefList->shrefs;i<HrefList->nhrefs;i++)
+  for(c= HrefList->shrefs; c < HrefList->nhrefs; c++)
   {
-    if(!strcmp(HrefList->Href[i].url,ehref))
+    if(!strcmp(HrefList->Href[c].url,ehref))
     {
-      HrefList->Href[i].stored = Href->stored;
-      HrefList->Href[i].referrer = Href->referrer;
-      HrefList->Href[i].hops = Href->hops;
-      HrefList->Href[i].method = Href->method;
-      HrefList->Href[i].stored = Href->stored;
-      HrefList->Href[i].site_id = Href->site_id;
-      HrefList->Href[i].server_id = Href->server_id;
-      HrefList->Href[i].rec_id = Href->rec_id;
-      HrefList->Href[i].max_doc_per_site = Href->max_doc_per_site;
+      HrefList->Href[c].stored = Href->stored;
+      HrefList->Href[c].referrer = Href->referrer;
+      HrefList->Href[c].hops = Href->hops;
+      HrefList->Href[c].method = Href->method;
+      HrefList->Href[c].stored = Href->stored;
+      HrefList->Href[c].site_id = Href->site_id;
+      HrefList->Href[c].server_id = Href->server_id;
+      HrefList->Href[c].rec_id = Href->rec_id;
+      HrefList->Href[c].max_doc_per_site = Href->max_doc_per_site;
+      UdmVarListFree(&HrefList->Href[c].Vars);
+      UdmVarListInit(&HrefList->Href[c].Vars);
+      UdmVarListReplaceLst(&HrefList->Href[c].Vars, &Href->Vars, NULL, "*");
       UDM_FREE(ehref);
       return(0);
     }
@@ -120,6 +135,9 @@ __C_LINK int __UDMCALL UdmHrefListAdd(UDM_HREFLIST * HrefList,UDM_HREF * Href)
   HrefList->Href[HrefList->nhrefs].server_id = Href->server_id;
   HrefList->Href[HrefList->nhrefs].rec_id = Href->rec_id;
   HrefList->Href[HrefList->nhrefs].max_doc_per_site= Href->max_doc_per_site;
+  UdmVarListInit(&HrefList->Href[HrefList->nhrefs].Vars);
+  UdmVarListReplaceLst(&HrefList->Href[HrefList->nhrefs].Vars,
+                       &Href->Vars, NULL, "*");
   HrefList->nhrefs++;
 
   /* Sort unsorted part */
@@ -140,7 +158,7 @@ extern __C_LINK void __UDMCALL UdmHrefListFree(UDM_HREFLIST * HrefList)
 {
   size_t i;
   for(i=0;i<HrefList->nhrefs;i++)
-    UDM_FREE(HrefList->Href[i].url);
+    UdmHrefFree(&HrefList->Href[i]);
   UDM_FREE(HrefList->Href);
   bzero((void*)HrefList, sizeof(*HrefList));
 }
