@@ -1361,7 +1361,13 @@ UdmDocAddCookieHeaders(UDM_ENV *Conf, UDM_DOCUMENT *Doc)
     else
     {
       size_t plen= strlen(path);
-      if (strncmp(Doc->CurURL.path, path, plen))
+      size_t path_length= strlen(Doc->CurURL.path);
+      if (memcmp(Doc->CurURL.path, path, udm_min(plen, path_length)))
+        continue;
+      if (plen > path_length && (!Doc->CurURL.filename ||
+                                  memcmp(Doc->CurURL.filename,
+                                         path + path_length,
+                                         plen - path_length)))
         continue;
     }
     short_dlen= path-domain;
