@@ -85,7 +85,15 @@ UDM_AGENT **ThreadIndexers;
 #ifdef WIN32
 HANDLE *threads;
 #ifdef CONSOLE
-#define localtime_r(x, y) localtime(x)
+
+#include <time.h>
+static struct tm*
+localtime_r(const time_t *clock, struct tm *result)
+{
+  *result= *localtime(clock);
+  return result;
+}
+
 #define strptime(x, y, z) (0)
 #endif
 #else
@@ -100,7 +108,7 @@ pthread_t *threads;
 #define UDM_DBTYPE "odbc"
 void UdmShowInfo(UDM_AGENT* A, const char *state, const char* str)
 {
-  printf("%d %s %s\n",A->handle,state,str);
+  printf("%d %s %s\n", A ? A->handle : 0,state,str);
 }
 #else
 extern __C_LINK void __UDMCALL UdmShowInfo(UDM_AGENT* A, const char *state, const char* str);
@@ -248,7 +256,10 @@ static int ShowStatistics(UDM_AGENT *Indexer)
   stat_time = UdmVarListFindStr(&Conf.Vars, "stat_time", "0");
   bzero(&tm, sizeof(tm));
 
-  if (stat_time && 
+  if (stat_time &&
+      strlen(stat_time) >= 7 &&
+      stat_time[4] == '-' &&
+      (stat_time[7] == '-' || !stat_time[7]) &&
       (strptime(stat_time, "%Y-%m-%d %H:%M:%S", &tm) ||
        strptime(stat_time, "%Y-%m-%d %H:%M", &tm) ||
        strptime(stat_time, "%Y-%m-%d %H:%M", &tm) ||
@@ -528,7 +539,7 @@ static int usage(int level)
 {
   fprintf(stderr, "\n");
   fprintf(stderr, "indexer from %s-%s-%s\n", PACKAGE, VERSION, UDM_DBTYPE);
-  fprintf(stderr, "http://www.mnogosearch.org/ (C)1998-2005, LavTech Corp.\n");
+  fprintf(stderr, "http://www.mnogosearch.org/ (C)1998-2006, LavTech Corp.\n");
   fprintf(stderr, "\n");
   fprintf(stderr, "Usage: indexer [OPTIONS]  [configfile]\n");
   fprintf(stderr, "\n");
