@@ -208,7 +208,14 @@ int UdmPrepareWords(UDM_AGENT * Indexer,UDM_DOCUMENT * Doc){
         
         tlen=lt-tok;
         
-        if (tlen <= max_word_len && tlen >= min_word_len)
+        
+        /*
+          Word lengths are checked later in indexer.c.
+          We cannot just skip this block here because
+          wordpos should be incremented even if we skip
+          a word. Otherwise we have phrase search problem.
+        */
+        /*if (tlen <= max_word_len && tlen >= min_word_len)*/
         {
         
           if (tlen > uwordlen)
@@ -250,10 +257,10 @@ int UdmPrepareWords(UDM_AGENT * Indexer,UDM_DOCUMENT * Doc){
       }
     }
     
-    if(Sec && Sec->curlen < Sec->maxlen)
+    if(Sec && Sec->curlen < Sec->maxlen &&
+       !(Item->flags & UDM_TEXTLIST_FLAG_SKIP_ADD_SECTION))
     {
       int cnvres;
-
       UdmReallocSection(Indexer,Sec);
 
       src = (char*)UStr;
@@ -262,7 +269,6 @@ int UdmPrepareWords(UDM_AGENT * Indexer,UDM_DOCUMENT * Doc){
       cnvres=UdmConv(&uni_lc,Sec->val+Sec->curlen,dstlen,src,srclen);
       Sec->curlen+=uni_lc.obytes;
       Sec->val[Sec->curlen]='\0';
-      
       if (cnvres<0)
       {
         Sec->curlen=Sec->maxlen;
@@ -306,9 +312,55 @@ int UdmPrepareWords(UDM_AGENT * Indexer,UDM_DOCUMENT * Doc){
 
 /**************************** Built-in Parsers ***************************/
 
-int UdmParseURLText(UDM_AGENT *A,UDM_DOCUMENT *Doc){
+static int
+UdmTextListAddWithConversion(UDM_DOCUMENT *Doc, 
+                             const char *name, const char *src, size_t secno,
+                             UDM_CONV *cnv)
+{
+  size_t tmplen= strlen(src);
+  size_t dstlen= tmplen * 8 + 1;
+  char *tmp= (char*) UdmMalloc(tmplen + 1);
+  char *dst= (char*) UdmMalloc(dstlen + 1);
+  
+  if (tmp != NULL && dst != NULL)
+  {
+    UDM_TEXTITEM Item;
+    char  sec_name[64];
+    UdmUnescapeCGIQuery(tmp, src);
+    UdmConv(cnv, dst, dstlen, tmp, strlen(tmp));
+    bzero(&Item, sizeof(Item));
+    udm_snprintf(sec_name, sizeof(sec_name), "%s", name);
+    Item.str= dst;
+    Item.section= secno;
+    Item.section_name= sec_name;
+    Item.flags= 0;
+    UdmTextListAdd(&Doc->TextList, &Item);
+  }
+  UDM_FREE(tmp);
+  UDM_FREE(dst);
+  return UDM_OK;  
+}
+
+
+static UDM_CHARSET *
+UdmVarListFindCharset(UDM_VARLIST *Lst, const char *name, UDM_CHARSET *def)
+{
+  UDM_CHARSET *res;
+  if ((name= UdmVarListFindStr(Lst, name, NULL)) && (res= UdmGetCharSet(name)))
+    return res;
+  return def;
+}
+
+int UdmParseURLText(UDM_AGENT *A,UDM_DOCUMENT *Doc)
+{
   UDM_TEXTITEM  Item;
-  UDM_VAR    *Sec;
+  UDM_VAR       *Sec;
+  UDM_CONV      cnv;
+  UDM_VARLIST   *V= &Doc->Sections;
+  UDM_CHARSET   *l1= UdmGetCharSet("latin1");
+  UDM_CHARSET   *rcs= UdmVarListFindCharset(V, "RemoteCharset", l1);
+  UDM_CHARSET   *fscs= UdmVarListFindCharset(V, "RemoteFileNameCharset", rcs);
+  UDM_CHARSET   *doccs= UdmVarListFindCharset(V, "CharSet", l1);
   
   Item.href=NULL;
   
@@ -318,6 +370,7 @@ int UdmParseURLText(UDM_AGENT *A,UDM_DOCUMENT *Doc){
     Item.str = UDM_NULL2EMPTY(Doc->CurURL.schema);
     Item.section=Sec->section;
     Item.section_name=sc;
+    Item.flags= 0;
     UdmTextListAdd(&Doc->TextList,&Item);
   }
   if((Sec=UdmVarListFind(&Doc->Sections,"url.host")))
@@ -326,29 +379,20 @@ int UdmParseURLText(UDM_AGENT *A,UDM_DOCUMENT *Doc){
     Item.str = UDM_NULL2EMPTY(Doc->CurURL.hostname);
     Item.section=Sec->section;
     Item.section_name=sc;
+    Item.flags= 0;
     UdmTextListAdd(&Doc->TextList,&Item);
   }
+  
+  UdmConvInit(&cnv, fscs, doccs, UDM_RECODE_HTML);
   if((Sec=UdmVarListFind(&Doc->Sections,"url.path")))
   {
-    char sc[]="url.path";
-    Item.str = UDM_NULL2EMPTY(Doc->CurURL.path);
-    Item.section=Sec->section;
-    Item.section_name=sc;
-    UdmTextListAdd(&Doc->TextList,&Item);
+    const char *src= UDM_NULL2EMPTY(Doc->CurURL.path);
+    UdmTextListAddWithConversion(Doc, Sec->name, src, Sec->section, &cnv);
   }
   if((Sec=UdmVarListFind(&Doc->Sections,"url.file")))
   {
-    char *str, sc[]="url.file";
-    str = (char*)UdmMalloc(strlen(UDM_NULL2EMPTY(Doc->CurURL.filename)) + 1);
-    if (str != NULL)
-    {
-      UdmUnescapeCGIQuery(str, UDM_NULL2EMPTY(Doc->CurURL.filename));
-      Item.str = str;
-      Item.section = Sec->section;
-      Item.section_name = sc;
-      UdmTextListAdd(&Doc->TextList, &Item);
-      UDM_FREE(str);
-    }
+    const char *src= UDM_NULL2EMPTY(Doc->CurURL.filename);
+    UdmTextListAddWithConversion(Doc, Sec->name, src, Sec->section,&cnv);
   }
   return UDM_OK;
 }
@@ -370,6 +414,7 @@ int UdmParseHeaders(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc)
       Item.str=Doc->Sections.Var[i].val;
       Item.section=Sec->section;
       Item.section_name=secname;
+      Item.flags= 0;
       UdmTextListAdd(&Doc->TextList,&Item);
     }
   }
@@ -390,6 +435,7 @@ int UdmParseText(UDM_AGENT * Indexer,UDM_DOCUMENT * Doc)
     Item.section=BSec->section;
     Item.str = udm_strtok_r(Doc->Buf.content, "\r\n", &lt);
     Item.section_name=sc;
+    Item.flags= 0;
     while(Item.str)
     {
       UdmTextListAdd(&Doc->TextList,&Item);
@@ -640,6 +686,27 @@ const char * UdmHTMLToken(const char * s, const char ** lt,UDM_HTMLTOK *t)
 }
 
 
+static void
+UdmDocAddHref(UDM_DOCUMENT *Doc, char *href, const char *crosstext)
+{
+  UDM_HREF Href;
+  UdmSGMLUnescape(href);
+  UdmHrefInit(&Href);
+  Href.referrer = UdmVarListFindInt(&Doc->Sections, "Referrer-ID", 0);
+  Href.hops=1+UdmVarListFindInt(&Doc->Sections,"Hops",0);
+  Href.site_id = UdmVarListFindInt(&Doc->Sections, "Site_id", 0);
+  Href.url=href;
+  Href.method=UDM_METHOD_GET;
+  if (crosstext)
+  {
+    urlid_t url_id= UdmVarListFindInt(&Doc->Sections, "ID", 0);
+    UdmVarListAddStr(&Href.Vars, "CrossText", crosstext);
+    UdmVarListAddInt(&Href.Vars, "Referrer-ID", url_id);
+  }
+  UdmHrefListAdd(&Doc->Hrefs,&Href);
+}
+
+
 int UdmHTMLParseTag(UDM_HTMLTOK * tag,UDM_DOCUMENT * Doc)
 {
   UDM_TEXTITEM Item;
@@ -731,6 +798,7 @@ int UdmHTMLParseTag(UDM_HTMLTOK * tag,UDM_DOCUMENT * Doc)
         Item.section = Sec->section;
         Item.section_name = secname;
         Item.href = NULL;
+        Item.flags= 0;
         UdmTextListAdd(&Doc->TextList, &Item);
         UDM_FREE(y);
       }
@@ -784,6 +852,7 @@ int UdmHTMLParseTag(UDM_HTMLTOK * tag,UDM_DOCUMENT * Doc)
       Item.section=Sec->section;
       Item.section_name=secname;
       Item.href = NULL;
+      Item.flags= 0;
       UdmTextListAdd(&Doc->TextList,&Item);
     }
     
@@ -888,18 +957,18 @@ int UdmHTMLParseTag(UDM_HTMLTOK * tag,UDM_DOCUMENT * Doc)
 
   if((href)&&(tag->follow!=UDM_FOLLOW_NO))
   {
-    UDM_HREF  Href;
-    UdmSGMLUnescape(href);
-    UdmHrefInit(&Href);
-    Href.referrer = UdmVarListFindInt(&Doc->Sections, "Referrer-ID", 0);
-    Href.hops=1+UdmVarListFindInt(&Doc->Sections,"Hops",0);
-    Href.site_id = UdmVarListFindInt(&Doc->Sections, "Site_id", 0);
-    Href.url=href;
-    Href.method=UDM_METHOD_GET;
-    UdmHrefListAdd(&Doc->Hrefs,&Href);
-    /* For crosswords */
-    UDM_FREE(tag->lasthref);
-    tag->lasthref = (char*)UdmStrdup(href);
+    if (strcasecmp(name, "a"))
+    {
+      /* No crosstext, add the link right now*/
+      UdmDocAddHref(Doc, href, NULL);
+    }
+    else
+    {
+      /* TODO: Postpone adding, for crosswords and SQLExportHref */
+      UDM_FREE(tag->lasthref);
+      tag->lasthref = (char*)UdmStrdup(href);
+      UdmDocAddHref(Doc, href, NULL);
+    }
   }
   UDM_FREE(metaname);
   UDM_FREE(metacont);
@@ -973,6 +1042,7 @@ int UdmHTMLParse(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc){
           Item.str=tmp;
           Item.section=body_sec;
           Item.section_name=scb;
+          Item.flags= 0;
 #if NOT_READY_YET
           if (tag.nonbreaking)
             UdmTextListAppend(&Doc->TextList, &Item);
@@ -987,6 +1057,7 @@ int UdmHTMLParse(UDM_AGENT *Indexer,UDM_DOCUMENT *Doc){
           Item.str=tmp;
           Item.section=title_sec;
           Item.section_name=sct;
+          Item.flags= 0;
           UdmTextListAdd(&Doc->TextList,&Item);
         }
         UDM_FREE(tmp);
