@@ -58,8 +58,6 @@ typedef struct
 #define UDM_XML_EXCLAM		'!'
 #define UDM_XML_CDATA		'D'
 
-#define UDM_XML_OK	0
-#define UDM_XML_ERROR	1
 
 
 typedef struct xml_attr_st
@@ -68,20 +66,6 @@ typedef struct xml_attr_st
   const char *end;
 } UDM_XML_ATTR;
 
-typedef struct xml_stack_st
-{
-  char errstr[128];
-  char attr[128];
-  char *attrend;
-  const char *beg;
-  const char *cur;
-  const char *end;
-  char question;
-  void *user_data;
-  int (*enter)(struct xml_stack_st *st, const char *val, size_t len);
-  int (*value)(struct xml_stack_st *st, const char *val, size_t len);
-  int (*leave_xml)(struct xml_stack_st *st, const char *val, size_t len);
-} UDM_XML_PARSER;
 
 static const char *UdmLex2str (int lex)
 {
@@ -247,7 +231,6 @@ static int UdmXMLLeave(UDM_XML_PARSER *p, const char *str, size_t slen)
 }
 
 
-static
 int UdmXMLParser (UDM_XML_PARSER *p, const char *str, size_t len)
 {
   p->attrend = p->attr;
@@ -397,48 +380,48 @@ gt:
   return(UDM_XML_OK);
 }
 
-static
+
 void UdmXMLParserCreate (UDM_XML_PARSER *p)
 {
   bzero((void*)p, sizeof(p[0]));
 }
 
-static
+
 void UdmXMLParserFree (UDM_XML_PARSER *p)
 {
 }
 
-static
+
 void UdmXMLSetValueHandler (UDM_XML_PARSER *p, int (*action)(UDM_XML_PARSER *p, const char *s, size_t l))
 {
   p->value = action;
 }
 
-static
+
 void UdmXMLSetEnterHandler (UDM_XML_PARSER *p, int (*action)(UDM_XML_PARSER *p, const char *s, size_t l))
 {
   p->enter = action;
 }
 
-static
+
 void UdmXMLSetLeaveHandler (UDM_XML_PARSER *p, int (*action)(UDM_XML_PARSER *p, const char *s, size_t l))
 {
   p->leave_xml = action;
 }
 
-static
+
 void UdmXMLSetUserData (UDM_XML_PARSER *p, void *user_data)
 {
   p->user_data = user_data;
 }
 
-static
+
 const char *UdmXMLErrorString (UDM_XML_PARSER *p)
 {
   return(p->errstr);
 }
 
-static
+
 size_t UdmXMLErrorPos (UDM_XML_PARSER *p)
 {
   const char *beg = p->beg;
@@ -451,7 +434,7 @@ size_t UdmXMLErrorPos (UDM_XML_PARSER *p)
   return(p->cur-beg);
 }
 
-static
+
 size_t UdmXMLErrorLineno (UDM_XML_PARSER *p)
 {
   size_t res = 0;
