@@ -28,6 +28,9 @@
 #ifdef   HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
 
 #include "udmsearch.h"
 #include "udm_xmalloc.h"
@@ -293,6 +296,32 @@ int UdmThreadJoin(void *thd)
 }        
 #endif
 
+
+static int CreateAlias(UDM_ENV *Conf, UDM_DOCUMENT *Doc)
+{
+  char *alcopy, *aliastr;
+  UDM_MATCH    *Alias;
+  UDM_MATCH_PART Parts[10];
+
+  /* Create "Alias" variable */
+  alcopy=UdmRemoveHiLightDup(UdmVarListFindStr(&Doc->Sections,"URL",""));
+  if ((Alias=UdmMatchListFind(&Conf->Aliases,alcopy,10,Parts)))
+  {
+    size_t nbytes= strlen(Alias->arg) + strlen(alcopy) + 64;
+    aliastr= (char*)UdmMalloc(nbytes);
+    UdmMatchApply(aliastr, nbytes, alcopy, Alias->arg, Alias, 10, Parts);
+  }
+  else
+  {
+    aliastr = (char*)UdmStrdup(alcopy);
+  }
+  UdmVarListReplaceStr(&Doc->Sections,"Alias", aliastr);
+  UdmFree(aliastr);
+  UdmFree(alcopy);
+  return UDM_OK;
+}
+
+
 int main(int argc, char ** argv)
 {
   const char  *env, *bcharset, *lcharset;
@@ -464,6 +493,11 @@ int main(int argc, char ** argv)
     return(0);
   }
 
+#ifdef HAVE_LOCALE_H
+  if ((env= UdmVarListFindStr(&Env->Vars, "Locale", NULL)))
+    setlocale(LC_ALL, env);
+#endif
+
 #ifdef HAVE_SETVBUF
   {
     /*
@@ -739,29 +773,13 @@ int main(int argc, char ** argv)
   {
     UDM_DOCUMENT *Doc=&Res->Doc[i];
     UDM_CATEGORY C;
-    UDM_MATCH    *Alias;
-    UDM_MATCH_PART Parts[10];
-    char         *aliastr, *alcopy, *clist, *eu;
+    char         *clist, *eu;
     const char   *u;
     size_t       cl, sc, clistsize;
     urlid_t      dc_url_id = (urlid_t)UdmVarListFindInt(&Doc->Sections, "ID", 0);
     urlid_t      dc_origin_id = (urlid_t)UdmVarListFindInt(&Doc->Sections, "Origin-ID", 0);
     
-    /* Create "Alias" variable */
-    alcopy=UdmRemoveHiLightDup(UdmVarListFindStr(&Doc->Sections,"URL",""));
-    if ((Alias=UdmMatchListFind(&Agent->Conf->Aliases,alcopy,10,Parts)))
-    {
-      size_t nbytes= strlen(Alias->arg) + strlen(alcopy) + 64;
-      aliastr= (char*)UdmMalloc(nbytes);
-      UdmMatchApply(aliastr, nbytes, alcopy, Alias->arg, Alias, 10, Parts);
-    }
-    else
-    {
-      aliastr = (char*)UdmStrdup(alcopy);
-    }
-    UdmVarListReplaceStr(&Doc->Sections,"Alias", aliastr);
-    UdmFree(aliastr);
-    UdmFree(alcopy);
+    CreateAlias(Agent->Conf, Doc);
     
     /* Skip clones */
     if (dc_origin_id)
@@ -782,6 +800,7 @@ int main(int argc, char ** argv)
         UdmVarListInit(&CloneVars);
         UdmVarListAddLst(&CloneVars,&Env->Vars,NULL,"*");
         UdmVarListReplaceLst(&CloneVars,&Clone->Sections,NULL,"*");
+        CreateAlias(Agent->Conf, Clone);
         clist = (char*)UdmRealloc(clist, (clistsize = strlen(clist)) + 2048);
         UdmTemplatePrint(Agent, NULL, clist + clistsize, 2048, &CloneVars, &tmpl, "clone");
         UdmVarListFree(&CloneVars);
