@@ -1110,6 +1110,9 @@ int UdmPrepare(UDM_AGENT * query,UDM_RESULT *Res)
 }
 
 
+#define NUMWORD_FACTOR_SIZE 256
+
+
 typedef struct udm_score_param_st
 {
   unsigned int *R;
@@ -1117,6 +1120,11 @@ typedef struct udm_score_param_st
   size_t ncosine;
   size_t nsections;
   float Rsum_factor;
+  int wf[256];
+  int wf2[256];
+  int nwf[256];
+  float numword_factor[NUMWORD_FACTOR_SIZE];
+  float numdistinctword_factor[NUMWORD_FACTOR_SIZE];
 } UDM_SCORE_PARAM;
 
 
@@ -1573,7 +1581,7 @@ static void UdmGroupByURLNewRel(UDM_RESULT *Res)
 }
 
 
-#define NUMWORD_FACTOR_SIZE 256
+
 #define NUMWORD_FACTOR(nwf, n) (nwf[n >= NUMWORD_FACTOR_SIZE ? NUMWORD_FACTOR_SIZE - 1 : n])
 #define MAXCOORD_FACTOR(factor, max_coord) ((1-((float)factor*(float)max_coord)))
 #define MINCOORD_FACTOR(factor, coord) ((float) 0x1000 / (float) (0x1000 + factor * (coord - 1)))
@@ -1649,7 +1657,6 @@ UdmGroupByURLInternal(UDM_AGENT *query,UDM_RESULT *Res, int search_mode)
   size_t nwf_offs= Res->WWList.nuniq * nsections + 1;
   size_t nwf_num= 0;  /* How many words in this section */
   size_t numcosine;
-  int wf[256], wf2[256], nwf[256];
   unsigned int *R, *D, *D_dst_offs, *D_nwf_offs;
   size_t Rsum;
   UDM_URL_CRD *Crd= Res->CoordList.Coords;
@@ -1657,9 +1664,8 @@ UdmGroupByURLInternal(UDM_AGENT *query,UDM_RESULT *Res, int search_mode)
   UDM_URL_CRD *CrdFrom, *CrdCurr;
   UDM_URL_CRD *CrdLast= Res->CoordList.Coords + Res->CoordList.ncoords;
   UDM_WIDEWORD *Res_WWList_Word= Res->WWList.Word;
-  UDM_SCORE_PARAM score_param;
+  UDM_SCORE_PARAM *score_param;
   float Rsum_factor;
-  float numword_factor[NUMWORD_FACTOR_SIZE];
   float numwordfactor= ((float)UdmVarListFindDouble(&query->Conf->Vars,
                                                 "NumWordFactor", 25.5)) / 255;
   float max_coord_factor= ((float)UdmVarListFindInt(&query->Conf->Vars,
@@ -1671,7 +1677,6 @@ UdmGroupByURLInternal(UDM_AGENT *query,UDM_RESULT *Res, int search_mode)
                                                   "MinCoordFactor", 0);
   unsigned int numdistinctwordfactor= (unsigned int) UdmVarListFindInt(&query->Conf->Vars,
                                                      "NumDistinctWordFactor", 0);
-  float numdistinctword_factor[NUMWORD_FACTOR_SIZE];
   if(!Res->CoordList.ncoords) return;
 
   if (0)
@@ -1680,21 +1685,24 @@ UdmGroupByURLInternal(UDM_AGENT *query,UDM_RESULT *Res, int search_mode)
     return;
   }
   
+  if (!(score_param= (UDM_SCORE_PARAM*)UdmMalloc(sizeof(UDM_SCORE_PARAM))))
+    return;
+  
   for (i= 0; i < Res->WWList.nuniq; i++)
   {
     unsigned int k= numdistinctwordfactor;
     float x= (float) i / Res->WWList.nuniq;
-    numdistinctword_factor[i]= ((x * x * x * x * k) + (256-k)) / 256;
+    score_param->numdistinctword_factor[i]= ((x * x * x * x * k) + (256-k)) / 256;
   }
   
   UdmWideWordListSetOriginWeight(&Res->WWList);
-  UdmNumWordFactorInit(numwordfactor, numword_factor, Res->CoordList.ncoords);
-  UdmWeightFactorsInit(UdmVarListFindStr(&query->Conf->Vars, "wf", ""), wf);
+  UdmNumWordFactorInit(numwordfactor, score_param->numword_factor, Res->CoordList.ncoords);
+  UdmWeightFactorsInit(UdmVarListFindStr(&query->Conf->Vars, "wf", ""), score_param->wf);
   for (i= 0; i < 256; i++)
-    wf2[i]= wf[i] << 2;
+    score_param->wf2[i]= score_param->wf[i] << 2;
   if (UdmVarListFindStr(&query->Conf->Vars, "nwf", NULL))
   {
-    UdmWeightFactorsInit(UdmVarListFindStr(&query->Conf->Vars, "nwf", ""), nwf);
+    UdmWeightFactorsInit(UdmVarListFindStr(&query->Conf->Vars, "nwf", ""), score_param->nwf);
     nwf_num= nsections;
   }  
 
@@ -1721,7 +1729,7 @@ UdmGroupByURLInternal(UDM_AGENT *query,UDM_RESULT *Res, int search_mode)
     for (secno= 0; secno < nsections; secno++)
     {
       size_t offs= Res_WWList_Word[i].order * nsections + secno;
-      R[offs] = wf2[secno] + Res_WWList_Word[i].weight;
+      R[offs] = score_param->wf2[secno] + Res_WWList_Word[i].weight;
       Rsum+= R[offs] * R[offs];
     }
   }
@@ -1778,11 +1786,11 @@ UdmGroupByURLInternal(UDM_AGENT *query,UDM_RESULT *Res, int search_mode)
     nitems = j;
   }
 
-  score_param.R= R;
-  score_param.D= D;
-  score_param.ncosine= numcosine;
-  score_param.nsections= nsections;
-  score_param.Rsum_factor= Rsum_factor;
+  score_param->R= R;
+  score_param->D= D;
+  score_param->ncosine= numcosine;
+  score_param->nsections= nsections;
+  score_param->Rsum_factor= Rsum_factor;
 
   for (CrdFrom= Crd ; CrdFrom < CrdLast ; CrdFrom= CrdCurr)
   {
@@ -1821,7 +1829,7 @@ UdmGroupByURLInternal(UDM_AGENT *query,UDM_RESULT *Res, int search_mode)
         for (z = 0; z < Res->WWList.nuniq; z++) if (count[z] == 0) break;
         if (z < Res->WWList.nuniq && count[z] == 0) continue;
     }
-    nword_factor= NUMWORD_FACTOR(numword_factor, phr_n) *
+    nword_factor= NUMWORD_FACTOR(score_param->numword_factor, phr_n) *
                   MAXCOORD_FACTOR(max_coord_factor, max_coord) *
                   MINCOORD_FACTOR(MinCoordFactor, min_coord);
 
@@ -1834,23 +1842,25 @@ UdmGroupByURLInternal(UDM_AGENT *query,UDM_RESULT *Res, int search_mode)
           nuniq++;
       }
       if (nuniq < Res->WWList.nuniq)
-        nword_factor= nword_factor * numdistinctword_factor[nuniq];
+        nword_factor= nword_factor * score_param->numdistinctword_factor[nuniq];
     }
 
     if (nwf_num)
     {
       bzero((void*)D, D_size);
       FillD(D, &Res->WWList, CrdFrom, phr_n,
-            nsections, wf2, nwf_num, D_nwf_offs, D_dst_offs, dst_weight);
-      UdmNWFNormalize(D_nwf_offs, nwf, nwf_num);
-      CrdTo->coord= UdmCalcCosineWeight(&score_param, nword_factor);
+            nsections, score_param->wf2, nwf_num,
+            D_nwf_offs, D_dst_offs, dst_weight);
+      UdmNWFNormalize(D_nwf_offs, score_param->nwf, nwf_num);
+      CrdTo->coord= UdmCalcCosineWeight(score_param, nword_factor);
     }
     else
     {
-      CrdTo->coord= UdmCalcCosineWeightQuick(&score_param,
+      CrdTo->coord= UdmCalcCosineWeightQuick(score_param,
                                              &Res->WWList,
                                              CrdFrom, phr_n,
-                                             wf2, nwf_num,
+                                             score_param->wf2,
+                                             nwf_num,
                                              dst_offs, dst_weight,
                                              nword_factor);
     }
@@ -1862,6 +1872,7 @@ UdmGroupByURLInternal(UDM_AGENT *query,UDM_RESULT *Res, int search_mode)
 
 err:
 
+  UDM_FREE(score_param);
   UDM_FREE(temp_items);
   UDM_FREE(D);
   UDM_FREE(R);
@@ -1955,6 +1966,7 @@ void UdmGroupBySite(UDM_AGENT *query, UDM_RESULT *Res)
   }
   dst->per_site= count;
   Res->CoordList.ncoords= dst - Res->CoordList.Data + 1;
+  UdmCopyCoordFromData(&Res->CoordList);
   return;
 }
 
