@@ -781,6 +781,9 @@ UdmSpellNormalize(UDM_SPELLLIST *Sl, UDM_AFFIXLIST *Al,
   UDM_SPELL *(*FindNext)(UDM_SPELLLIST *Sl_arg, UDM_SPELL *Prev_arg, UDM_SPSEARCH_INFO *si);
   UDM_SPSEARCH_INFO Si;
 
+  if (len + 1 > sizeof(wrd))
+    return 0;
+  
   if (Sl->fmt == UDM_SPELL_FMT_HASH)
   {
     FindFirst= UdmSpellListFindFirstHash;
@@ -803,6 +806,9 @@ UdmSpellNormalize(UDM_SPELLLIST *Sl, UDM_AFFIXLIST *Al,
 
     rootlen= len - Ab->replen;
 
+    if (len + Ab->replen + Ab->findlen + 1 > sizeof(wrd))
+      continue;
+
     if (Ab->type == 's' && !memcmp(word + rootlen, Ab->repl, Ab->replen))
     {
       memcpy(wrd, word, rootlen);
@@ -962,7 +968,7 @@ ex:
 
 
 #ifdef HAVE_MYSQL_FULLTEXT_PLUGIN
-
+#define MYSQL_DYNAMIC_PLUGIN 1
 #undef PACKAGE
 #undef VERSION
 
