@@ -168,7 +168,15 @@ static int UdmPgSQLQueryInternal(UDM_DB *db, UDM_SQLRES *res,
   {
     PQclear(PGres);
     sprintf(db->errstr, "%s", PQerrorMessage(pgsql));
+#ifdef PG_DIAG_SQLSTATE
+    {
+      char *sqlstate= PQresultErrorField(PGres, PG_DIAG_SQLSTATE);
+      if (sqlstate && !strcmp(sqlstate, "23505"))
+        return UDM_OK;
+    }
+#endif
     if(strstr(db->errstr,"uplicate") ||
+       strstr(db->errstr, "duplicada") ||
        strstr(db->errstr, "") ||
        strstr(db->errstr, "повторный") ||
        strcasestr(db->errstr,"Duplizierter"))
