@@ -212,6 +212,16 @@ typedef struct udm_odbc_field_st
 } UDM_ODBC_FIELD;
 
 
+static int
+UdmODBCTypeIsBinary(int Type)
+{
+  return  Type == SQL_BINARY ||
+          Type == SQL_VARBINARY ||
+          Type == SQL_LONGVARBINARY ||
+          Type == -98/* DB2 SQL_BLOB */;
+}
+
+
 static int execDB(UDM_DB*db,UDM_SQLRES *result, const char *sqlstr)
 {
   RETCODE rc;
@@ -284,7 +294,7 @@ static int execDB(UDM_DB*db,UDM_SQLRES *result, const char *sqlstr)
     {
       SQLDescribeCol(sdb->hstmt, col+1,
                      Field[col].Name, 
-                     (SQLSMALLINT) sizeof(Field[col].Name - 1),
+                     (SQLSMALLINT) sizeof(Field[col].Name) - 1,
                      &Field[col].NameLen,
                      &Field[col].Type,
                      &Field[col].Size,
@@ -314,15 +324,37 @@ static int execDB(UDM_DB*db,UDM_SQLRES *result, const char *sqlstr)
       {
         size_t offs=result->nRows*iResColumns+i;
         const char *p;
+        char *tmp= NULL;
         SDWORD  pcbValue;
-        SWORD   get_type= Field[i].Type == SQL_FLOAT ? SQL_C_FLOAT : SQL_CHAR;
+        SWORD   get_type;
 
+        if (Field[i].Type == SQL_FLOAT)
+        {
+          get_type= SQL_FLOAT;
+        }
         if (Field[i].Type == SQL_DOUBLE)
+        {
           get_type= SQL_C_DOUBLE;
-
-        /* PostgreSQL bytea */
-        if (Field[i].Type == SQL_VARBINARY && db->DBType == UDM_DB_PGSQL)
-          get_type= SQL_C_BINARY;
+        }
+        else if (UdmODBCTypeIsBinary(Field[i].Type))
+        {
+          /*
+            PostgreSQL bytea
+            MSSQL BLOB
+            XTG Interbase/FireBird BLOB
+            Oracle BLOB
+            Sybase IMAGE & VARBINARY
+          */
+          if (db->DBType == UDM_DB_PGSQL ||
+              db->DBType == UDM_DB_MSSQL ||
+              db->DBType == UDM_DB_IBASE ||
+              db->DBType == UDM_DB_ORACLE8 ||
+              db->DBType == UDM_DB_SYBASE ||
+              db->DBType == UDM_DB_MYSQL)
+            get_type= SQL_C_BINARY;
+          else
+            get_type= SQL_CHAR;
+        }
 
 #ifdef HAVE_UNIXODBC
         /*
@@ -330,19 +362,37 @@ static int execDB(UDM_DB*db,UDM_SQLRES *result, const char *sqlstr)
            ODBC driver in conjunction with unixODBC always returns 4
            in pcbValue if get_type is SQL_CHAR. Let's fetch as SQL_C_SLONG.
         */
-        if (Field[i].Type == SQL_INTEGER && db->DBType == UDM_DB_SYBASE)
+        else if (Field[i].Type == SQL_INTEGER && db->DBType == UDM_DB_SYBASE)
           get_type= SQL_C_SLONG;
 #endif
+        else
+          get_type= SQL_CHAR;
 
         rc= SQLGetData(sdb->hstmt,i+1,get_type,bindbuf,sizeof(bindbuf),&pcbValue);
-        if ((rc != SQL_SUCCESS) || (pcbValue == SQL_NULL_DATA))
+        if (rc == SQL_SUCCESS_WITH_INFO)
         {
-          p= "";
-          pcbValue= 0;
+          if (pcbValue > sizeof(bindbuf) &&
+              (tmp= UdmMalloc(pcbValue)))
+          {
+            SDWORD tmp_pcbValue;
+            memcpy(tmp, bindbuf, sizeof(bindbuf));
+            rc= SQLGetData(sdb->hstmt,i+1,get_type,tmp+sizeof(bindbuf),pcbValue - sizeof(bindbuf),&tmp_pcbValue);
+            p= tmp;
+          }
+          else
+          {
+            p= "";
+            pcbValue= 0;
+          }
         }
-        else
+        else if (rc == SQL_SUCCESS)
         {
-          if (get_type == SQL_C_FLOAT)
+          if (pcbValue == SQL_NULL_DATA)
+          {
+            bindbuf[0]= '\0';
+            pcbValue= 0;
+          }
+          else if (get_type == SQL_C_FLOAT)
           {
             float num;
             memcpy(&num, bindbuf, sizeof(num));
@@ -362,18 +412,12 @@ static int execDB(UDM_DB*db,UDM_SQLRES *result, const char *sqlstr)
           }
           p= bindbuf;
         }
-        /* if(p)UdmRTrim(p," "); */
-        if (db->DBType != UDM_DB_ORACLE8 &&
-            db->DBType != UDM_DB_PGSQL &&
-#ifdef HAVE_UNIXODBC
-            db->DBType != UDM_DB_SYBASE &&
-#endif
-            (Field[i].Type == SQL_BINARY ||
-             Field[i].Type == SQL_VARBINARY ||
-             Field[i].Type == SQL_LONGVARBINARY ||
-             Field[i].Type == -98 /* DB2 SQL_BLOB */))
+
+
+        if (get_type != SQL_C_BINARY &&
+            UdmODBCTypeIsBinary(Field[i].Type))
         {
-          DecodeHexStr(bindbuf,&result->Items[offs],pcbValue);
+          DecodeHexStr(p, &result->Items[offs], pcbValue);
         }
         else
         {
@@ -382,6 +426,8 @@ static int execDB(UDM_DB*db,UDM_SQLRES *result, const char *sqlstr)
           result->Items[offs].val[pcbValue]='\0';
           result->Items[offs].len= pcbValue;
         }
+        if (tmp)
+          UdmFree(tmp);
       }
       result->nRows++;
     }
@@ -1073,9 +1119,10 @@ ex_display_dlen(CS_DATAFMT * column)
   {
     case CS_CHAR_TYPE:
     case CS_VARCHAR_TYPE:
+    case CS_LONGCHAR_TYPE:
     case CS_TEXT_TYPE:
     case CS_IMAGE_TYPE:
-      len = MIN(column->maxlength, MAX_CHAR_BUF);
+      len = MIN(column->maxlength*2+2, MAX_CHAR_BUF);
       break;
 
     case CS_BINARY_TYPE:
@@ -1164,8 +1211,12 @@ int ex_fetch_data(UDM_DB *db, UDM_SQLRES *res, CS_COMMAND *cmd)
 
     datafmt[i].maxlength = ex_display_dlen(&datafmt[i]) + 1;
     datafmt[i].datatype = CS_CHAR_TYPE;
+#ifdef CS_CURRENT_VERSION
+    if (CS_CURRENT_VERSION >= 15000)
+      datafmt[i].datatype= CS_LONGCHAR_TYPE;
+#endif
     datafmt[i].format   = CS_FMT_NULLTERM;
-    
+
     /* Allocate data */
     coldata[i].value = (CS_CHAR *)UdmMalloc((size_t)datafmt[i].maxlength);
     
@@ -1768,6 +1819,29 @@ char * UdmDBEscStr(int DBType,char *to,const char *from,size_t len)
   {
     while(*from)
     {
+#ifdef WIN32
+      /*
+        A workaround against a bug in SQLExecDirect
+        in PostgreSQL ODBC driver. It produces
+        an error when meets a question mark in a string
+        constant. For some reasons question marks are
+        considered as parameters. This should not happen
+        with SQLExecDirect.
+        Let's escape question mark using \x3F notation.
+      */
+      if (DBType == UDM_DB_PGSQL &&
+          (*from == '?' ||
+           *from == '{' ||
+           *from == '}'))
+      {
+        *to++= '\\';
+        *to++= 'x';
+        *to++= '3';
+        *to++= 'F';
+        *from++;
+        continue;
+      }
+#endif
       switch(*from)
       {
         case '\'':
