@@ -52,6 +52,7 @@ static int UdmUniNSpace(int c)
 {
   if (c > 0x0020)
   {
+    if (c == 0x00A0) return 0;
     if (c < 0x1680)
       return 1;
     if (c == 0x1680) return 0;
@@ -229,6 +230,8 @@ __C_LINK char * __UDMCALL UdmExcerptDoc (UDM_AGENT *Agent,
     else if (j && UdmUniNSpace(Source[j - 1]))
       Source[j++] = 0x20;
   }
+  if (j && !UdmUniNSpace(Source[j-1]))
+    j--;
   Source[j] = 0;
   ul = j;
 
