@@ -231,6 +231,8 @@ UDM_WIDEWORDLIST * UdmSynonymListFind(const UDM_SYNONYMLIST * List,UDM_WIDEWORD
       else
       {
         first->s.order= wword->order;
+        first->s.phrpos= wword->phrpos;
+        first->s.phrlen= wword->phrlen;
         first->s.origin= UDM_WORD_ORIGIN_SYNONYM;
         UdmWideWordListAdd(Res,&first->s);
       }
@@ -245,6 +247,8 @@ UDM_WIDEWORDLIST * UdmSynonymListFind(const UDM_SYNONYMLIST * List,UDM_WIDEWORD
       else
       {
         last->s.order= wword->order;
+        last->s.phrpos= wword->phrpos;
+        last->s.phrlen= wword->phrlen;
         last->s.origin= UDM_WORD_ORIGIN_SYNONYM;
         UdmWideWordListAdd(Res,&last->s);
       }
@@ -269,6 +273,8 @@ UDM_WIDEWORDLIST * UdmSynonymListFind(const UDM_SYNONYMLIST * List,UDM_WIDEWORD
           else
           {
             first->s.order= wword->order;
+            first->s.phrpos= wword->phrpos;
+            first->s.phrlen= wword->phrlen;
             first->s.origin= UDM_WORD_ORIGIN_SYNONYM;
             UdmWideWordListAdd(Res,&first->s);
           }
@@ -282,8 +288,10 @@ UDM_WIDEWORDLIST * UdmSynonymListFind(const UDM_SYNONYMLIST * List,UDM_WIDEWORD
           }
           else
           {
-            last->s.order=wword->order;
-            last->s.origin = UDM_WORD_ORIGIN_SYNONYM;
+            last->s.order= wword->order;
+            last->s.phrpos= wword->phrpos;
+            last->s.phrlen= wword->phrlen;
+            last->s.origin= UDM_WORD_ORIGIN_SYNONYM;
             UdmWideWordListAdd(Res,&last->s);
           }
         }
