@@ -1335,6 +1335,12 @@ static int HtmlTemplateCompile(UDM_TMPL_PRG *prg, const char *template)
       break;
     tok=GetHtmlTok(NULL, &lt, &HtmlTok);
   }
+  
+  if (rc == UDM_OK && st.nitems)
+  {
+    udm_snprintf(prg->errstr, sizeof(prg->errstr), "Missing ENDIF or ENDWHILE");
+    rc= UDM_ERROR;
+  }
   CompileStackFree(&st);
   return rc;
 }
