@@ -87,7 +87,7 @@ outp:
       }
       else if (res == UDM_CHARSET_ILUNI && wc[i] != '?')
       {
-        if (c->flags && UDM_RECODE_HTML)
+        if (c->flags & UDM_RECODE_HTML_NONASCII)
         {
           if ( d_e - d > 8)
           {
