@@ -96,10 +96,27 @@ UDM_DSTR *UdmDSTRInit (UDM_DSTR *dstr, size_t size_page) {
 }
 
 void UdmDSTRFree (UDM_DSTR *dstr) {
+	dstr->size_total= dstr->size_data= 0;
 	UdmFree(dstr->data);
 	if (dstr->free) UdmFree(dstr);
 }
 
+
+int UdmDSTRAlloc (UDM_DSTR *dstr, size_t size_data)
+{
+  size_t asize;
+ 
+  if (size_data <= dstr->size_total) return(UDM_OK);
+  asize= (size_data / dstr->size_page + 1) * dstr->size_page;
+  dstr->size_total= dstr->size_data= 0;
+  UdmFree(dstr->data);
+  if (!(dstr->data= UdmMalloc(asize)))
+    return UDM_ERROR;
+  dstr->size_total= asize;
+  return UDM_OK;
+}
+
+
 int UdmDSTRRealloc (UDM_DSTR *dstr, size_t size_data)
 {
   char *tmp;
