@@ -55,9 +55,8 @@ typedef struct udm_var_handler_st
 } UDM_VARHANDLER;
 
 
-static int varcmp(void *v1, void *v2)
+static int varcmp(const UDM_VAR *uv1, const UDM_VAR *uv2)
 {
-  register UDM_VAR *uv1 = v1, *uv2 = v2;
   if (uv1->name == NULL)
   {
     if (uv2->name == NULL)
@@ -229,7 +228,7 @@ static int UdmVarListMethodEnvFind(UDM_VARLIST *Vars, UDM_VAR *Var,
       New->val= (char*) Res;
       New->handler= &ResultVar;
       New->name= UdmStrdup(resname);
-      UdmSort(Vars->Var, Vars->nvars, sizeof(UDM_VAR), (qsort_cmp)varcmp);
+      UdmSort(Vars->Var, Vars->nvars, sizeof(UDM_VAR), (udm_qsort_cmp)varcmp);
       
       udm_snprintf(prmname, sizeof(prmname), "%s.first", resname);
       UdmVarListReplaceInt(Vars, prmname, (int)Res->first);
@@ -248,6 +247,7 @@ static int UdmVarListMethodEnvFind(UDM_VARLIST *Vars, UDM_VAR *Var,
 static int UdmVarListMethodEnvSQLQuery(UDM_VARLIST *Vars, UDM_VAR *Var,
                                    UDM_VAR **args, size_t nargs)
 {
+#ifdef HAVE_SQL
   if (Var->handler->type == UDM_VAR_ENV && nargs==2)
   {
     UDM_ENV *Env= (UDM_ENV*) Var->val;
@@ -271,12 +271,13 @@ static int UdmVarListMethodEnvSQLQuery(UDM_VARLIST *Vars, UDM_VAR *Var,
       New->val= (char*) Res;
       New->handler= &SQLResultVar;
       New->name= UdmStrdup(resname);
-      UdmSort(Vars->Var, Vars->nvars, sizeof(UDM_VAR), (qsort_cmp)varcmp);
+      UdmSort(Vars->Var, Vars->nvars, sizeof(UDM_VAR), (udm_qsort_cmp)varcmp);
       udm_snprintf(prmname, sizeof(prmname), "%s.num_rows", resname);
       UdmVarListReplaceUnsigned(Vars, prmname, UdmSQLNumRows(Res));
     }
     UdmAgentFree(&Agent);
   }
+#endif
   return UDM_OK;
 }
 
@@ -361,8 +362,10 @@ static int UdmVarCreateSQLResult(UDM_VARHANDLER *ha, UDM_VAR *dst,
 
 static void UdmVarFreeSQLResult(UDM_VAR *V)
 {
+#ifdef HAVE_SQL
   UdmSQLFree((UDM_SQLRES*)V->val);
   UdmFree(V->val);
+#endif
 }
 
 
@@ -375,6 +378,7 @@ static int UdmVarCopyValueSQLResult(UDM_VAR *D, UDM_VAR *S)
 static int UdmVarListMethodResultSQLFetch(UDM_VARLIST *Vars, UDM_VAR *Var,
                                        UDM_VAR **args, size_t nargs)
 {
+#ifdef HAVE_SQL
   if (Var->handler->type == UDM_VAR_SQLRESULT && nargs == 2 && args[1]->val)
   {
     UDM_SQLRES *Res= (UDM_SQLRES*) Var->val;
@@ -394,6 +398,7 @@ static int UdmVarListMethodResultSQLFetch(UDM_VARLIST *Vars, UDM_VAR *Var,
       Res->curRow++;
     }
   }
+#endif
   return UDM_OK;
 }
 /******************************** /SQLResult ***********************/
@@ -466,7 +471,7 @@ int UdmVarListCreateObject(UDM_VARLIST *Vars, const char *name, int type,
     New= &Vars->Var[Vars->nvars-1];
     h->Create(h, New, args, nargs);
     New->name= UdmStrdup(name);
-    UdmSort(Vars->Var, Vars->nvars, sizeof(UDM_VAR), (qsort_cmp)varcmp);
+    UdmSort(Vars->Var, Vars->nvars, sizeof(UDM_VAR), (udm_qsort_cmp)varcmp);
   }
   return UDM_OK;
 }
@@ -533,7 +538,7 @@ int UdmVarListAdd(UDM_VARLIST * Lst,UDM_VAR * S)
   if (!New->handler)
     New->handler= &SimpleVar;
   Lst->nvars++;
-  if(S) UdmSort(Lst->Var, Lst->nvars, sizeof(UDM_VAR), (qsort_cmp)varcmp);
+  if(S) UdmSort(Lst->Var, Lst->nvars, sizeof(UDM_VAR), (udm_qsort_cmp)varcmp);
   return UDM_OK;
 }
 
@@ -543,7 +548,7 @@ static int UdmVarListAddNamed(UDM_VARLIST *Lst,UDM_VAR *S, const char *name)
   UdmVarListAdd(Lst,NULL);
   v=&Lst->Var[Lst->nvars-1];
   UdmVarCopy(v,S,name);
-  UdmSort(Lst->Var, Lst->nvars, sizeof(UDM_VAR), (qsort_cmp)varcmp);
+  UdmSort(Lst->Var, Lst->nvars, sizeof(UDM_VAR), (udm_qsort_cmp)varcmp);
   return UDM_OK;
 }
 
@@ -553,7 +558,7 @@ UDM_VAR * UdmVarListFind(UDM_VARLIST * vars,const char * name)
   
   if (!vars->nvars) return NULL;
   key.name= (char*)name;
-  return (UDM_VAR*)bsearch(&key, vars->Var, vars->nvars, sizeof(UDM_VAR), (qsort_cmp)varcmp);
+  return (UDM_VAR*)bsearch(&key, vars->Var, vars->nvars, sizeof(UDM_VAR), (udm_qsort_cmp)varcmp);
 }
 
 int UdmVarListDelBySection(UDM_VARLIST *vars, int sec)
@@ -641,7 +646,7 @@ static int UdmVarListReplaceNamed(UDM_VARLIST *Lst,UDM_VAR *S, const char *name)
     UdmVarListAdd(Lst,NULL);
     v=&Lst->Var[Lst->nvars-1];
     rc=UdmVarCopy(v,S,name);
-    UdmSort(Lst->Var, Lst->nvars, sizeof(UDM_VAR), (qsort_cmp)varcmp);
+    UdmSort(Lst->Var, Lst->nvars, sizeof(UDM_VAR), (udm_qsort_cmp)varcmp);
   }
   return rc;
 }
@@ -655,7 +660,7 @@ static int UdmVarListInsNamed(UDM_VARLIST *Lst,UDM_VAR *S, const char *name)
     UdmVarListAdd(Lst,NULL);
     v=&Lst->Var[Lst->nvars-1];
     rc=UdmVarCopy(v,S,name);
-    UdmSort(Lst->Var, Lst->nvars, sizeof(UDM_VAR), (qsort_cmp)varcmp);
+    UdmSort(Lst->Var, Lst->nvars, sizeof(UDM_VAR), (udm_qsort_cmp)varcmp);
   }
   return rc;
 }
@@ -716,7 +721,7 @@ int UdmVarListAddStrWithSection(UDM_VARLIST *vars,
   New->curlen= (val != NULL) ? strlen(val) : 0;  
   New->name= name ? (char*)UdmStrdup(name) : NULL;
   New->val= val ? (char*)UdmStrdup(val) : NULL;
-  UdmSort(vars->Var, vars->nvars, sizeof(UDM_VAR), (qsort_cmp)varcmp);
+  UdmSort(vars->Var, vars->nvars, sizeof(UDM_VAR), (udm_qsort_cmp)varcmp);
   return vars->nvars;
 }
 
@@ -972,3 +977,22 @@ int UdmVarListAddEnviron(UDM_VARLIST *Vars, const char *name)
   UDM_FREE(str);
   return UDM_OK;
 }
+
+int UdmVarListConvert(UDM_VARLIST *Vars, UDM_CONV *conv)
+{
+  size_t i;
+  for (i= 0; i < Vars->nvars; i++)
+  {
+    UDM_VAR *Var= &Vars->Var[i];
+    if (UdmVarType(Var) == UDM_VAR_STR)
+    {
+      size_t len= strlen(Var->val), newlen;
+      char *newval= (char*)UdmMalloc(len * 12 + 1);
+      newlen= UdmConv(conv, newval, len * 12 + 1, Var->val, len + 1);
+      UDM_FREE(Var->val);
+      Var->val= newval;
+      Var->curlen= newlen;
+    }
+  }
+  return UDM_OK;
+}
