@@ -73,6 +73,20 @@ int UdmWordListFree(UDM_WORDLIST * List)
   return(0);
 }
 
+
+void UdmWideWordInit(UDM_WIDEWORD *W)
+{
+  bzero((void*)W, sizeof(UDM_WIDEWORD));
+}
+
+
+void UdmWideWordFree(UDM_WIDEWORD *W)
+{
+  UDM_FREE(W->word);
+  UDM_FREE(W->uword);
+}
+
+
 UDM_WORDLIST * UdmWordListInit(UDM_WORDLIST * List)
 {
   bzero((void*)List, sizeof(*List));
@@ -97,6 +111,12 @@ size_t UdmWideWordListAdd(UDM_WIDEWORDLIST * List,UDM_WIDEWORD * Word)
         (UdmUniStrCmp(List->Word[i].uword, Word->uword) == 0))
     {
       List->Word[i].count+= Word->count;
+      if (List->Word[i].phrpos != Word->phrpos ||
+          List->Word[i].phrlen != Word->phrlen)
+      {
+        List->Word[i].phrpos= 0; /* No certain in-phrase position */
+        List->Word[i].phrlen= 0;
+      }
       switch (Word->origin)
       {
       case UDM_WORD_ORIGIN_QUERY:
@@ -113,17 +133,20 @@ size_t UdmWideWordListAdd(UDM_WIDEWORDLIST * List,UDM_WIDEWORD * Word)
   
   /* Realloc memory */
   List->Word= (UDM_WIDEWORD*)UdmRealloc(List->Word,sizeof(*(List->Word))*(List->nwords+1));
-  bzero((void*)&List->Word[List->nwords], sizeof(*(List->Word)));
+  UdmWideWordInit(&List->Word[List->nwords]);
   
   /* Copy data */
   List->Word[List->nwords].len= Word->len;
   List->Word[List->nwords].order= Word->order;
+  List->Word[List->nwords].phrpos= Word->phrpos;
+  List->Word[List->nwords].phrlen= Word->phrlen;
   List->Word[List->nwords].count= Word->count;
   List->Word[List->nwords].word = Word->word ? (char*)UdmStrdup(Word->word) : NULL;
   List->Word[List->nwords].uword= Word->uword ? UdmUniDup(Word->uword) : NULL;
   List->Word[List->nwords].ulen= Word->uword ? UdmUniLen(Word->uword) : 0;
   List->Word[List->nwords].origin= Word->origin;
   List->Word[List->nwords].match= Word->match;
+  List->Word[List->nwords].secno= Word->secno;
   List->nwords++;
   return(List->nwords);
 }
@@ -132,10 +155,7 @@ void UdmWideWordListFree(UDM_WIDEWORDLIST * List)
 {
   size_t i;
   for(i=0;i<List->nwords;i++)
-  {
-    UDM_FREE(List->Word[i].word);
-    UDM_FREE(List->Word[i].uword);
-  }
+    UdmWideWordFree(&List->Word[i]);
   UDM_FREE(List->Word);
   UdmWideWordListInit(List);
 }
